/*
 * Copyright (c) 2010 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */

package de.intevation.gnv.artifactdatabase.client;

import java.util.Locale;

import org.apache.log4j.Logger;

/**
 * Used to start a session with a new artifact. A new
 * <code>DefaultArtifactDatabaseClient</code> is created.
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 *
 */
public class ArtifactDatabaseClientFactory {

    /**
     * the logger, used to log exceptions and additonaly information
     */
    private static Logger log = Logger
            .getLogger(ArtifactDatabaseClientFactory.class);

    /**
     * The singleton Instance of this Factory.
     */
    private static ArtifactDatabaseClientFactory instance = null;

    /**
     * Constructor
     */
    private ArtifactDatabaseClientFactory() {
        super();
    }

    /**
     * This Method provides an singleton Instance of this Class.
     *
     * @return an singleton Instance of this Class
     */
    public static synchronized ArtifactDatabaseClientFactory getInstance() {
        if (instance == null) {
            instance = new ArtifactDatabaseClientFactory();
        }
        return instance;
    }

    /**
     * Getting the ArtifactDatabaseClient
     * @param locale teh Local that should be used for the Communication
     * @return the ArtifactDatabaseClient
     */
    public ArtifactDatabaseClient getArtifactDatabaseClient(Locale locale) {
        DefaultArtifactDatabaseClient adc = new DefaultArtifactDatabaseClient();
        adc.setLocale(locale);
        return adc;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
